@@ -8,9 +8,9 @@ from paco.application.reseng_ec2 import EC2ResourceEngine
 from paco.application.reseng_elasticacheredis import ElastiCacheRedisResourceEngine
 from paco.application.reseng_eventsrule import EventsRuleResourceEngine
 from paco.application.reseng_lambda import LambdaResourceEngine
-from paco.application.reseng_lbapplication import LBApplicationResourceEngine
-from paco.application.reseng_lbclassic import LBClassicResourceEngine
-from paco.application.reseng_rds import RDSMysqlResourceEngine, DBParameterGroupResourceEngine
+from paco.application.reseng_lb import LBApplicationResourceEngine, LBNetworkResourceEngine
+from paco.application.reseng_rds import RDSMysqlResourceEngine, RDSMysqlAuroraResourceEngine, RDSPostgresqlResourceEngine, \
+    RDSPostgresqlAuroraResourceEngine, DBParameterGroupResourceEngine, DBClusterParameterGroupResourceEngine
 from paco.application.reseng_snstopic import SNSTopicResourceEngine
 from paco.application.reseng_s3bucket import S3BucketResourceEngine
 from paco.application.reseng_eip import EIPResourceEngine
@@ -18,3 +18,13 @@ from paco.application.reseng_ebs import EBSResourceEngine
 from paco.application.reseng_codedeployapplication import CodeDeployApplicationResourceEngine
 from paco.application.reseng_dashboard import DashboardResourceEngine
 from paco.application.reseng_elasticsearch import ElasticsearchDomainResourceEngine
+from paco.application.reseng_iottopicrule import IoTTopicRuleResourceEngine
+from paco.application.reseng_iotanalyticspipeline import IoTAnalyticsPipelineResourceEngine
+from paco.application.reseng_iotpolicy import IoTPolicyResourceEngine
+from paco.application.reseng_ecscluster import ECSClusterResourceEngine
+from paco.application.reseng_ecsservices import ECSServicesResourceEngine
+from paco.application.reseng_ecrrepository import ECRRepositoryResourceEngine
+from paco.application.reseng_iamuser import IAMUserResourceEngine
+from paco.application.reseng_pinpointapplication import PinpointApplicationResourceEngine
+from paco.application.reseng_cognito import CognitoIdentityPoolResourceEngine, CognitoUserPoolResourceEngine
+from paco.application.reseng_dynamodb import DynamoDBResourceEngine
