@@ -40,6 +40,9 @@ class ResourceEngine():
     def init_monitoring(self):
         "Add an Alarms template with Alarms specific to the Resource"
         # If alarm_sets exist init alarms for them
+        if schemas.IDeploymentPipeline.providedBy(self.resource):
+            # Ignore DeploymentPipeline Alarms: TBD
+            return
         if schemas.IRDSAurora.providedBy(self.resource):
             # RDS Aurora can have alarms for each individual DB Instance
             for db_instance in self.resource.db_instances.values():
@@ -49,8 +52,7 @@ class ResourceEngine():
                     monitoring = getattr(self.resource.default_instance, 'monitoring', None)
                     db_instance.monitoring = monitoring
                 if monitoring != None and monitoring.enabled and \
-                    getattr(monitoring, 'alarm_sets', None) != None and \
-                    len(monitoring.alarm_sets.values()) > 0:
+                    getattr(monitoring, 'alarm_sets', None) != None:
                     self.stack_group.add_new_stack(
                         self.aws_region,
                         db_instance,
@@ -74,8 +76,7 @@ class ResourceEngine():
                 )
         elif getattr(self.resource, 'monitoring', None) != None and \
             self.resource.monitoring.enabled and \
-            getattr(self.resource.monitoring, 'alarm_sets', None) != None and \
-            len(self.resource.monitoring.alarm_sets.values()) > 0:
+            getattr(self.resource.monitoring, 'alarm_sets', None) != None:
             self.stack_group.add_new_stack(
                 self.aws_region,
                 self.resource,
