@@ -7,8 +7,8 @@ from paco.models.references import get_model_obj_from_ref
 from paco.models.resources import SSMDocument
 from paco.models import schemas
 from paco.stack import StackHooks
-from paco.utils import md5sum
 from paco import models
+from paco import utils
 import json
 import os
 import pathlib
@@ -18,6 +18,176 @@ import shutil
 yaml=YAML()
 yaml.default_flow_sytle = False
 
+ECR_DEPLOY_SCRIPT_HEAD = """
+#!/bin/bash
+. {paco_base_path}/EC2Manager/ec2lm_functions.bash
+
+OVERRIDE_SOURCE_DEPLOY_TAG="$1"
+
+declare -a ECR_DEPLOY_LIST=({ecr_deploy_list})
+
+RELEASE_PHASE_TAG='release-phase'
+"""
+
+ECR_DEPLOY_SCRIPT_CONFIG = """
+
+{ecr_deploy_name}_SOURCE_REPO_NAME_{idx}='{source_repo_name}'
+{ecr_deploy_name}_SOURCE_REPO_DOMAIN_{idx}='{source_repo_domain}'
+{ecr_deploy_name}_SOURCE_REPO_URI_{idx}="${{{ecr_deploy_name}_SOURCE_REPO_DOMAIN_{idx}}}/"
+{ecr_deploy_name}_SOURCE_TAG_{idx}='{source_tag}'
+{ecr_deploy_name}_DEST_REPO_NAME_{idx}='{dest_repo_name}'
+{ecr_deploy_name}_DEST_REPO_DOMAIN_{idx}='{dest_repo_domain}'
+{ecr_deploy_name}_DEST_REPO_URI_{idx}="${{{ecr_deploy_name}_DEST_REPO_DOMAIN_{idx}}}/"
+{ecr_deploy_name}_DEST_TAG_{idx}='{dest_tag}'
+{ecr_deploy_name}_RELEASE_PHASE_{idx}=$(echo "{release_phase}" | tr '[:upper:]' '[:lower:]')
+
+"""
+
+
+
+ECR_DEPLOY_SCRIPT_BODY = """
+function run_command()
+{
+    DESCRIPTION=$1
+    COMMAND=$2
+    if [ "${DESCRIPTION}" == "" ] ; then
+	    DESCRIPTION="${COMMAND}"
+    fi
+    echo -n "${DESCRIPTION}: "
+    OUTPUT=$(eval $COMMAND 2>&1)
+    EXIT_CODE=$?
+
+    if [ ${EXIT_CODE} -eq 0 ] ; then
+	    echo "success"
+    else
+        echo "ERROR: failed"
+        echo "${COMMAND}"
+        echo "${OUTPUT}"
+        exit ${EXIT_CODE}
+    fi
+    return 0
+}
+
+echo "--------------------------------------------------------------------------"
+echo "Pulling from Source"
+ENABLE_RELEASE_PHASE=false
+REPO_LOGIN=[]
+for (( I=0; I<${#ECR_DEPLOY_LIST[@]}; I++ ))
+do
+    ECR_DEPLOY_LEN=${ECR_DEPLOY_LIST[$I]}_ECR_DEPLOY_LEN
+    # Login to the ECR Repositories
+    echo "Authenticating Docker with the ECR Repositories"
+    SOURCE_REPO_AUTH_DONE=""
+    DEST_REPO_AUTH_DONE=""
+    for (( J=0; J<${!ECR_DEPLOY_LEN}; J++ ))
+    do
+
+        SOURCE_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_NAME_$J
+        SOURCE_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_DOMAIN_$J
+        SOURCE_REPO_URI=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_URI_$J
+        SOURCE_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_SOURCE_TAG_$J
+        if [ "${OVERRIDE_SOURCE_DEPLOY_TAG}" != "" ] ; then
+            SOURCE_DEPLOY_TAG="OVERRIDE_SOURCE_DEPLOY_TAG"
+        fi
+
+        DEST_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_NAME_$J
+        DEST_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_DOMAIN_$J
+        DEST_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_DEST_TAG_$J
+        DEST_REPO_URI=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_URI_$J
+
+        RELEASE_PHASE=${ECR_DEPLOY_LIST[$I]}_RELEASE_PHASE_$J
+
+        if [[ "${SOURCE_REPO_AUTH_DONE}" != *"${!SOURCE_REPO_DOMAIN}"* ]] ; then
+            run_command "docker login source: ${!SOURCE_REPO_DOMAIN}" "aws ecr get-login-password | docker login --username AWS --password-stdin ${!SOURCE_REPO_DOMAIN}"
+            SOURCE_REPO_AUTH_DONE="${SOURCE_REPO_AUTH_DONE} ${!SOURCE_REPO_DOMAIN}"
+        fi
+        if [[ "${DEST_REPO_AUTH_DONE}" != *"${!DEST_REPO_DOMAIN}"* ]] ; then
+            run_command "docker login destination: ${!DEST_REPO_DOMAIN}" "aws ecr get-login-password | docker login --username AWS --password-stdin ${!DEST_REPO_DOMAIN}"
+            DEST_REPO_AUTH_DONE="${DEST_REPO_AUTH_DONE} ${!DEST_REPO_DOMAIN}"
+        fi
+
+        ec2lm_async_run "" "docker pull ${!SOURCE_REPO_URI}${!SOURCE_REPO_NAME[$I]}:${!SOURCE_DEPLOY_TAG}"
+    done
+
+    ec2lm_async_run_wait
+
+    for (( J=0; J<${!ECR_DEPLOY_LEN}; J++ ))
+    do
+
+        SOURCE_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_NAME_$J
+        SOURCE_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_DOMAIN_$J
+        SOURCE_REPO_URI=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_URI_$J
+        SOURCE_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_SOURCE_TAG_$J
+        if [ "${OVERRIDE_SOURCE_DEPLOY_TAG}" != "" ] ; then
+            SOURCE_DEPLOY_TAG="OVERRIDE_SOURCE_DEPLOY_TAG"
+        fi
+
+        DEST_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_NAME_$J
+        DEST_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_DOMAIN_$J
+        DEST_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_DEST_TAG_$J
+        DEST_REPO_URI=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_URI_$J
+
+        RELEASE_PHASE=${ECR_DEPLOY_LIST[$I]}_RELEASE_PHASE_$J
+
+        if [ "${!RELEASE_PHASE}" == 'true' ] ; then
+            ENABLE_RELEASE_PHASE=true
+            #run_command "docker tag ${!SOURCE_REPO_NAME}:${!SOURCE_DEPLOY_TAG} ${!DEST_REPO_NAME}:${DEPLOY_TAG}" "docker tag ${!SOURCE_REPO_URI}${!SOURCE_REPO_NAME}:${!SOURCE_DEPLOY_TAG} ${!DEST_REPO_URI}\
+${!DEST_REPO_NAME}:${RELEASE_PHASE_TAG}"
+            run_command "" "docker tag ${!SOURCE_REPO_URI}${!SOURCE_REPO_NAME}:${!SOURCE_DEPLOY_TAG} ${!DEST_REPO_URI}${!DEST_REPO_NAME}:${RELEASE_PHASE_TAG}"
+            #run_command "" "docker push ${!DEST_REPO_URI}${!DEST_REPO_NAME}:${RELEASE_PHASE_TAG}"
+            ec2lm_async_run "" "docker push ${!DEST_REPO_URI}${!DEST_REPO_NAME}:${RELEASE_PHASE_TAG}"
+        fi
+    done
+
+    ec2lm_async_run_wait
+
+    echo "--------------------------------------------------------------------------"
+    if [ "${ENABLE_RELEASE_PHASE}" == 'true' ] ; then
+        echo "Release Phase: start"
+        /usr/local/bin/paco-ecs-release-phase-${ECR_DEPLOY_LIST[$I]} ${RELEASE_PHASE_TAG}
+        RET=$?
+        if [ $RET -ne 0 ] ; then
+            echo "ERROR: Release Phase failed. Aborting deployment."
+            exit $RET
+        fi
+        echo "Release Phase: done"
+    else
+        echo "Relase Phase: disabled"
+    fi
+
+    echo "--------------------------------------------------------------------------"
+    echo "Ready to deploy source images to destination"
+    echo
+    read -p "Type 'deploy' to continue: " ANSWER
+    if [ "${ANSWER}" != "deploy" ] ; then
+        echo "Answer does not match, aborting deployment."
+        exit 1
+    fi
+
+    echo "--------------------------------------------------------------------------"
+    echo "Pushing to Destination"
+
+    for (( J=0; J<${!ECR_DEPLOY_LEN}; J++ ))
+    do
+        SOURCE_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_NAME_$J
+        SOURCE_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_DOMAIN_$J
+        SOURCE_REPO_URI=${ECR_DEPLOY_LIST[$I]}_SOURCE_REPO_URI_$J
+        SOURCE_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_SOURCE_TAG_$J
+        if [ "${OVERRIDE_SOURCE_DEPLOY_TAG}" != "" ] ; then
+            SOURCE_DEPLOY_TAG="OVERRIDE_SOURCE_DEPLOY_TAG"
+        fi
+
+        DEST_REPO_NAME=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_NAME_$J
+        DEST_REPO_DOMAIN=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_DOMAIN_$J
+        DEST_DEPLOY_TAG=${ECR_DEPLOY_LIST[$I]}_DEST_TAG_$J
+        DEST_REPO_URI=${ECR_DEPLOY_LIST[$I]}_DEST_REPO_URI_$J
+
+        run_command "" "docker tag ${!SOURCE_REPO_URI}${!SOURCE_REPO_NAME}:${!SOURCE_DEPLOY_TAG} ${!DEST_REPO_URI}${!DEST_REPO_NAME}:${!DEST_DEPLOY_TAG}"
+        ec2lm_async_run "" "docker push ${!DEST_REPO_URI}${!DEST_REPO_NAME}:${!DEST_DEPLOY_TAG}"
+    done
+    ec2lm_async_run_wait
+done
+"""
 
 RELEASE_PHASE_SCRIPT = """#!/bin/bash -e
 
@@ -64,7 +234,7 @@ function register_task_definition() {
     mv ${TEMP_FILE}.new ${TEMP_FILE}
 
     # remove status, compatibilities, taskDefinitionArn, requiresAttributes, revision
-    for FIELD in 'status' 'compatibilities' 'taskDefinitionArn' 'requiresAttributes' 'revision'
+    for FIELD in 'registeredAt' 'registeredBy' 'status' 'compatibilities' 'taskDefinitionArn' 'requiresAttributes' 'revision'
     do
         JQ_PATTERN="del(.taskDefinition.${FIELD})"
         #echo cat "${TEMP_FILE} | jq \\"${JQ_PATTERN}\\" > ${TEMP_FILE}.new"
@@ -73,16 +243,12 @@ function register_task_definition() {
     done
 
     # Remove json that is invalid for 'aws ecs register-task-definition'
-    #echo sed -iE 's/^{$//' ${TEMP_FILE}
     sed -iE 's/^{$//' ${TEMP_FILE}
-    #echo sed -iE 's/^.*"taskDefinition": {.*/{/' ${TEMP_FILE}
     sed -iE 's/^.*"taskDefinition": {.*/{/' ${TEMP_FILE}
-    #echo sed -iE 's/^}$//' ${TEMP_FILE}
     sed -iE 's/^}$//' ${TEMP_FILE}
 
     # Create new task definition
     FAMILY="paco-release-phase-"$(echo ${RELEASE_PHASE_NAME} | tr '.' '-')
-    #echo aws ecs register-task-definition --family ${FAMILY} --cli-input-json file://${TEMP_FILE}
     echo "${ECHO_PREFIX}: register_task_definition: registering: ${FAMILY}"
     TASK_DEFINITION_ARN=$(aws ecs register-task-definition --family ${FAMILY} --cli-input-json file://${TEMP_FILE} --query "taskDefinition.taskDefinitionArn" --output text)
 
@@ -98,13 +264,37 @@ function run_task() {
     local RELEASE_PHASE_NAME=$2
 
     echo "${ECHO_PREFIX}: run_task: ${RELEASE_PHASE_NAME}"
+    echo "aws ecs run-task --cluster ${CLUSTER_ID} --task-definition ${REGISTERED_TASK_DEFINITION_ARN} --tags \"key=PACO-RELEASE-PHASE,value=${RELEASE_PHASE_NAME}\" --query 'tasks[0].[taskArn,containerInstanceArn]' --output text"
     RESPONSE=$(aws ecs run-task --cluster ${CLUSTER_ID} --task-definition ${REGISTERED_TASK_DEFINITION_ARN} --tags "key=PACO-RELEASE-PHASE,value=${RELEASE_PHASE_NAME}" --query 'tasks[0].[taskArn,containerInstanceArn]' --output text)
+    echo "RESPONSE: ${RESPONSE}"
     TASK_ARN=$(echo $RESPONSE | awk '{print $1}')
     CONTAINER_INSTANCE_ARN=$(echo $RESPONSE | awk '{print $2}')
     TASK_ID=$(echo $TASK_ARN |awk -F '/' '{print $3}')
+    while :
+    do
+        if [ "${CONTAINER_INSTANCE_ARN}" != "" ]; then
+            break
+        fi
+        RESPONSE=$(aws ecs describe-tasks --cluster ${CLUSTER_ID} --tasks ${TASK_ID} --query 'tasks[0].[taskArn,containerInstanceArn]' --output text)
+        TASK_ARN=$(echo $RESPONSE | awk '{print $1}')
+        CONTAINER_INSTANCE_ARN=$(echo $RESPONSE | awk '{print $2}')
+    done
+
     ECS_INSTANCE_ID="$(aws ecs describe-container-instances --cluster ${CLUSTER_ID} --container-instances ${CONTAINER_INSTANCE_ARN} --query 'containerInstances[0].ec2InstanceId' --output text)"
     echo "${ECHO_PREFIX}: run-task: pending: ${TASK_ARN}"
+    set +e
     aws ecs wait tasks-running --cluster ${CLUSTER_ID} --task ${TASK_ARN}
+    RET=$?
+    if [ $RET -ne 0 ] ; then
+        LAST_STATUS=$(aws ecs describe-tasks --cluster ${CLUSTER_ID} --tasks ${TASK_ID} --query 'tasks[0].[lastStatus]' --output text)
+        if [ "$LAST_STATUS" == "STOPPED" ] ; then
+            STOPPED_REASON=$(aws ecs describe-tasks --cluster ${CLUSTER_ID} --tasks ${TASK_ID} --query 'tasks[0].[stoppedReason]' --output text)
+            echo "Stopped Reason: $STOPPED_REASON"
+        fi
+        aws ecs describe-tasks --cluster ${CLUSTER_ID} --tasks ${TASK_ID} --query 'tasks[0]'
+        exit $RET
+    fi
+    set -e
     echo "${ECHO_PREFIX}: run-task: running: ${TASK_ARN}"
 }
 
@@ -163,17 +353,18 @@ function stale_task_check() {
 # -----------------------------
 # Task Docker Exec
 function task_docker_exec() {
-   local CLUSTER_ID=$1
+    local CLUSTER_ID=$1
     local TASK_ID=$2
     local ECS_INSTANCE_ID=$3
-    local RELEASE_PHASE_COMMAND=$4
+    local RELEASE_PHASE_COMMAND="$4"
 
     RES=0
-
     echo "${ECHO_PREFIX}: task_docker_exec: command start: ${TASK_ID}"
+    echo "${ECHO_PREFIX}: task_docker_exec: command: ${RELEASE_PHASE_COMMAND}"
+    echo "${ECHO_PREFIX}: task_docker_exec: Instance Id: ${ECS_INSTANCE_ID}"
     TASK_DOCKER_ID=$(aws ecs describe-tasks --cluster ${CLUSTER_ID} --tasks ${TASK_ID} --query 'tasks[0].containers[0].runtimeId' --output text)
-    # echo aws ssm send-command --instance-ids ${ECS_INSTANCE_ID} --document-name paco_ecs_docker_exec --parameters TaskId=${TASK_DOCKER_ID},Command=${RELEASE_PHASE_COMMAND} --query 'Command.CommandId' --output text
-    COMMAND_ID=$(aws ssm send-command --instance-ids ${ECS_INSTANCE_ID} --document-name paco_ecs_docker_exec --parameters TaskId=${TASK_DOCKER_ID},Command=${RELEASE_PHASE_COMMAND} --query 'Command.CommandId' --output text)
+    echo aws ssm send-command --instance-ids ${ECS_INSTANCE_ID} --document-name paco_ecs_docker_exec --parameters TaskId=${TASK_DOCKER_ID},Command="${RELEASE_PHASE_COMMAND}" --query 'Command.CommandId' --output text
+    COMMAND_ID=$(aws ssm send-command --instance-ids ${ECS_INSTANCE_ID} --document-name paco_ecs_docker_exec --parameters TaskId=${TASK_DOCKER_ID},Command="${RELEASE_PHASE_COMMAND}" --query 'Command.CommandId' --output text)
     #echo "${ECHO_PREFIX}: task_docker_exec: COMMAND_ID: ${COMMAND_ID}"
 
     while :
@@ -192,9 +383,9 @@ function task_docker_exec() {
         fi
 
         COMMAND_STATUS_DETAILS="$(echo $COMMAND_STATE | jq -r '.StatusDetails')"
-        #echo "${ECHO_PREFIX}: task_docker_exec: COMMAND_STATUS_DETAILS: ${COMMAND_STATUS_DETAILS}"
+        echo "${ECHO_PREFIX}: task_docker_exec: COMMAND_STATUS_DETAILS: ${COMMAND_STATUS_DETAILS}"
         COMMAND_STDOUT="$(echo $COMMAND_STATE | jq -r '.StandardOutputContent')"
-        #echo "${ECHO_PREFIX}: task_docker_exec: COMMAND_STDOUT: ${COMMAND_STDOUT}"
+        echo "${ECHO_PREFIX}: task_docker_exec: COMMAND_STDOUT: ${COMMAND_STDOUT}"
 
         if [ "${COMMAND_STATUS}" == "Failed" ] ; then
             COMMAND_STDERR="$(echo $COMMAND_STATE | jq -r '.StandardErrorContent')"
@@ -236,7 +427,7 @@ function run_release_phase() {
     run_task ${CLUSTER_ID} ${RELEASE_PHASE_NAME}
 
     # 4. Execute the release phase script
-    task_docker_exec ${CLUSTER_ID} ${TASK_ID} ${ECS_INSTANCE_ID} ${RELEASE_PHASE_COMMAND}
+    task_docker_exec ${CLUSTER_ID} ${TASK_ID} ${ECS_INSTANCE_ID} "${RELEASE_PHASE_COMMAND}"
     EXEC_RES=$?
 
     # 5. stop the task
@@ -257,6 +448,32 @@ function run_release_phase() {
 
 """
 
+RELEASE_PHASE_SCRIPT_SSM_DOCUMENT_CONTENT = {
+                "schemaVersion": "2.2",
+                "description": "Paco ECS Release Phase Docker Exec",
+                "parameters": {
+                    "TaskId": {
+                        "type": "String",
+                        "description": "ECS Docker Task Id"
+                    },
+                    "Command": {
+                        "type": "String",
+                        "description": "Command to execute in the task container"
+                    }
+                },
+                "mainSteps": [
+                    {
+                        "action": "aws:runShellScript",
+                        "name": "ECSTaskDockerExec",
+                        "inputs": {
+                            "runCommand": [
+                                '/usr/bin/docker exec {{TaskId}} {{Command}}',
+                            ]
+                        }
+                    }
+                ]
+            }
+
 class DeploymentPipelineResourceEngine(ResourceEngine):
 
     def __init__(self, app_engine, grp_id, res_id, resource, stack_tags):
@@ -275,7 +492,7 @@ class DeploymentPipelineResourceEngine(ResourceEngine):
         self.codecommit_role_name = 'codecommit_role'
         self.github_role_name = 'github_role'
         self.source_stage = None
-        self.codebuild_ecs_release_phase_cache_id = ""
+        self.codebuild_ecs_release_phase_cache_id = RELEASE_PHASE_SCRIPT
 
     def init_stage(self, stage_config):
         "Initialize an Action in a Stage: for source/build/deploy-style"
@@ -299,6 +516,8 @@ class DeploymentPipelineResourceEngine(ResourceEngine):
             method(stage, action)
 
     def init_resource(self):
+        if self.pipeline.is_enabled() == False:
+            return
         self.pipeline.resolve_ref_obj = self
         self.pipeline.configuration.resolve_ref_obj = self
         self.pipeline_account_ctx = self.paco_ctx.get_account_context(self.pipeline.configuration.account)
@@ -395,6 +614,21 @@ class DeploymentPipelineResourceEngine(ResourceEngine):
                 if action.type == 'ECR.Source':
                     self.add_ecr_source_hooks(action)
 
+
+        # Pipeline Execution Notification Rules
+        # Create Notifications Rules CFTemplate
+        # Get the SNS topic to attach
+        env_name = '.'.join(self.app_engine.app.paco_ref_parts.split('.')[0:2])
+        notification_rules_stack = self.stack_group.add_new_stack(
+            self.aws_region,
+            self.resource,
+            cftemplates.NotificationRules,
+            account_ctx=self.pipeline_account_ctx,
+            stack_tags=self.stack_tags,
+            support_resource_ref_ext='notification_rules',
+            extra_context={'env_name': env_name, 'app_name': self.app.name}
+        )
+
         # Add CodeBuild Role ARN to KMS Key principal now that the role is created
         kms_config_dict['crypto_principal']['aws'] = self.kms_crypto_principle_list
         kms_stack = self.stack_group.add_new_stack(
@@ -688,9 +922,7 @@ policies:
         zip_path = work_path / 'zip'
         pathlib.Path(zip_path).mkdir(parents=True, exist_ok=True)
         os.chdir(zip_path)
-        image_def_path = zip_path / 'imagedefinitions.json'
-        with open(image_def_path, "w") as output_fd:
-            output_fd.write(file_contents)
+        utils.write_to_file(zip_path, 'imagedefinitions.json', file_contents)
         archive_path = work_path / 'imagedef'
         shutil.make_archive(archive_path, 'zip', zip_path)
         os.chdir(orig_cwd)
@@ -838,11 +1070,8 @@ run_release_phase "${{CLUSTER_ID_{idx}}}" "${{SERVICE_ID_{idx}}}" "${{RELEASE_PH
 
         unqiue_folder_name = config.paco_ref_parts
         build_folder = os.path.join(self.paco_ctx.build_path, 'ReleasePhase', unqiue_folder_name)
-        pathlib.Path(build_folder).mkdir(parents=True, exist_ok=True)
         file_path = os.path.join(build_folder, release_phase_script_name)
-        with open(file_path, "w") as output_fd:
-            output_fd.write(release_phase_script)
-        self.codebuild_ecs_release_phase_cache_id = md5sum(str_data=release_phase_script)
+        utils.write_to_file(build_folder, release_phase_script_name, release_phase_script)
 
         s3_ctl = self.paco_ctx.get_controller('S3')
         pipeline_config = get_parent_by_interface(config, schemas.IDeploymentPipeline)
@@ -857,32 +1086,7 @@ run_release_phase "${{CLUSTER_ID_{idx}}}" "${{SERVICE_ID_{idx}}}" "${{RELEASE_PH
         if 'paco_ecs_docker_exec' not in ssm_documents:
             ssm_doc = SSMDocument('paco_ecs_docker_exec', ssm_documents)
             ssm_doc.add_location(self.account_ctx.paco_ref, self.aws_region)
-            content = {
-                "schemaVersion": "2.2",
-                "description": "Paco ECS Release Phase Docker Exec",
-                "parameters": {
-                    "TaskId": {
-                        "type": "String",
-                        "description": "ECS Docker Task Id"
-                    },
-                    "Command": {
-                        "type": "String",
-                        "description": "Command to execute in the task container"
-                    }
-                },
-                "mainSteps": [
-                    {
-                        "action": "aws:runShellScript",
-                        "name": "ECSTaskDockerExec",
-                        "inputs": {
-                            "runCommand": [
-                                '/usr/bin/docker exec {{TaskId}} "{{Command}}"',
-                            ]
-                        }
-                    }
-                ]
-            }
-            ssm_doc.content = json.dumps(content)
+            ssm_doc.content = json.dumps(RELEASE_PHASE_SCRIPT_SSM_DOCUMENT_CONTENT)
             ssm_doc.document_type = 'Command'
             ssm_doc.enabled = True
             ssm_documents['paco_ecs_docker_exec'] = ssm_doc
