@@ -13,7 +13,7 @@ class EC2ResourceEngine(ResourceEngine):
             # ToDo: remove old-school use of env_ctx.netenv_id
             extra_context={
                 'netenv_name': self.env_ctx.netenv_id,
-                'env_name': self.env_id,
+                'env_name': self.env_name,
                 'app_name': self.app_id,
             },
         )
