@@ -19,6 +19,7 @@ from paco.cftemplates.nat_gateway import NATGateway
 from paco.cftemplates.kms import KMS
 from paco.cftemplates.cw_alarms import CWAlarms
 from paco.cftemplates.lambda_function import Lambda
+from paco.cftemplates.lambda_function import LambdaSNSSubscriptions
 from paco.cftemplates.eventsrule import EventsRule
 from paco.cftemplates.snstopics import SNSTopics
 from paco.cftemplates.sns import SNS
@@ -52,3 +53,4 @@ from paco.cftemplates.iamuser import IAMUser
 from paco.cftemplates.pinpointapplication import PinpointApplication
 from paco.cftemplates.cognito import CognitoUserPool, CognitoIdentityPool
 from paco.cftemplates.dynamodb import DynamoDB
+from paco.cftemplates.notification_rules import NotificationRules
