@@ -2,6 +2,7 @@
 CloudFormation template for CloudWatch Log Groups
 """
 
+from botocore.exceptions import ClientError
 from paco.cftemplates.cftemplates import StackTemplate
 from paco.models import references, schemas
 from paco.models.locations import get_parent_by_interface
@@ -26,10 +27,17 @@ class LogGroups(StackTemplate):
         # CloudWatch Agent logging
         cw_logging = get_parent_by_interface(stack.resource, schemas.IProject)['cw_logging']
         default_retention = cw_logging.expire_events_after_days
-        for log_group in stack.resource.monitoring.log_sets.get_all_log_groups():
+        if schemas.IRDSAurora.providedBy(stack.resource):
+            monitoring = stack.resource.default_instance.monitoring
+        else:
+            monitoring = stack.resource.monitoring
+        for log_group in monitoring.log_sets.get_all_log_groups():
             cfn_export_dict = {}
             log_group_name = log_group.get_full_log_group_name()
-            prefixed_log_group_name = prefixed_name(stack.resource, log_group_name, self.paco_ctx.legacy_flag)
+            if log_group.external_resource == False:
+                prefixed_log_group_name = prefixed_name(stack.resource, log_group_name, self.paco_ctx.legacy_flag)
+            else:
+                prefixed_log_group_name = log_group_name
             loggroup_logical_id = self.create_cfn_logical_id('LogGroup' + log_group_name)
 
             # provide prefixed LogGroup name as a CFN Parameter
@@ -56,11 +64,13 @@ class LogGroups(StackTemplate):
             if retention != 'Never':
                 cfn_export_dict["RetentionInDays"] = retention
 
-            log_group_resource = troposphere.logs.LogGroup.from_dict(
-                loggroup_logical_id,
-                cfn_export_dict
-            )
-            template.add_resource(log_group_resource)
+            # Avoid creating loggroup if it already exists as an external resource
+            if log_group.external_resource == False:
+                log_group_resource = troposphere.logs.LogGroup.from_dict(
+                    loggroup_logical_id,
+                    cfn_export_dict
+                )
+                template.add_resource(log_group_resource)
 
             # Metric Filters
             for metric_filter in log_group.metric_filters.values():
@@ -80,7 +90,7 @@ class LogGroups(StackTemplate):
                         'MetricNamespace': namespace,
                         'MetricValue': transf.metric_value
                     }
-                    if type(transf.default_value) == type(float):
+                    if isinstance(transf.default_value, float):
                         mts_dict['DefaultValue'] = transf.default_value
                     mt_list.append(mts_dict)
                 mf_dict['MetricTransformations'] = mt_list
@@ -88,7 +98,8 @@ class LogGroups(StackTemplate):
                     self.create_cfn_logical_id('MetricFilter' + metric_filter.name),
                     mf_dict,
                 )
-                metric_filter_resource.DependsOn = log_group_resource
+                if log_group.external_resource == False:
+                    metric_filter_resource.DependsOn = log_group_resource
                 template.add_resource(metric_filter_resource)
 
         # SSM Agent logging
@@ -115,3 +126,38 @@ class LogGroups(StackTemplate):
                     cfn_export_dict
                 )
                 template.add_resource(log_group_resource)
+
+        # Sneak in setting the template so that we can add a stack hook
+        # from a template
+        stack.template = self
+        stack.hooks.add(
+            name='DeleteLogGroups.' + self.resource.name,
+            stack_action=['delete'],
+            stack_timing='post',
+            hook_method=self.stack_hook_delete_log_groups,
+            cache_method=None,
+            hook_arg=monitoring
+        )
+
+    #def stack_hook_delete_log_groups_cache(self, hook, config):
+    #    "Cache method for LogGroups"
+    #    cp = asg.ecs.capacity_provider
+    #    return md5sum(str_data=f"{cp.managed_instance_protection}-{asg.paco_ref}-{cp.is_enabled()}-{cp.target_capacity}-{cp.minimum_scaling_step_size}-{cp.maximum_scaling_step_size}")
+
+    def stack_hook_delete_log_groups(self, hook, monitoring_config):
+        logs_client = self.account_ctx.get_aws_client('logs', self.aws_region)
+        for log_group in monitoring_config.log_sets.get_all_log_groups():
+            root_log_group_name = log_group.get_full_log_group_name()
+            log_group_name = root_log_group_name
+            if log_group.external_resource == False:
+                log_group_name = prefixed_name(self.stack.resource, root_log_group_name, self.paco_ctx.legacy_flag)
+            try:
+                logs_client.delete_log_group(
+                    logGroupName=log_group_name
+                )
+            except ClientError as error:
+                # Ignore gorups that do not exist
+                if error.response['Error']['Code'] != 'ResourceNotFoundException':
+                    print(f'ERROR: Unable to delete LogGroup: {log_group_name}: {error.response["Error"]["Code"]}')
+
+
