@@ -38,28 +38,46 @@ class Route53HostedZone(StackTemplate):
                 )
             self.template.add_resource(hosted_zone_res)
             hosted_zone_id_output_value = troposphere.Ref(hosted_zone_res)
-            nameservers_output_value = troposphere.Join(',', troposphere.GetAtt(hosted_zone_res, 'NameServers'))
+            # NameServers attribute is not supported for private hosted zones
+            if zone_config.private_hosted_zone == False:
+                nameservers_output_value = troposphere.Join(',', troposphere.GetAtt(hosted_zone_res, 'NameServers'))
 
         self.create_output(
             title='HostedZoneId',
             value=hosted_zone_id_output_value,
             ref=config_ref+'.id'
         )
-        self.create_output(
-            title='HostedZoneNameServers',
-            value=nameservers_output_value,
-            ref=config_ref+'.name_servers'
-        )
+        # NameServers attribute is not supported for private hosted zones (except external resources)
+        if zone_config.private_hosted_zone == False or (zone_config.external_resource != None and zone_config.external_resource.is_enabled()):
+            self.create_output(
+                title='HostedZoneNameServers',
+                value=nameservers_output_value,
+                ref=config_ref+'.name_servers'
+            )
 
         if len(zone_config.record_sets) > 0:
             record_set_list = []
             for record_set_config in zone_config.record_sets:
-                record_set_res = troposphere.route53.RecordSet(
-                    Name=record_set_config.record_name,
-                    Type=record_set_config.type,
-                    TTL=record_set_config.ttl,
-                    ResourceRecords=record_set_config.resource_records
-                )
+                record_set_dict = {
+                    'Name': record_set_config.record_name,
+                }
+                if record_set_config.type == 'Alias':
+                    record_set_dict['Type'] = 'A'
+                    if record_set_config.resource_records[0].find('cloudfront.net') != -1:
+                        hosted_zone_id = 'Z2FDTNDATAQYW2'
+                    elif record_set_config.resource_records[0].find('elb.amazonaws.com') != -1:
+                        elb_region = record_set_config.resource_records[0].split('.')[1]
+                        hosted_zone_id = self.lb_hosted_zone_id('alb', elb_region)
+                    record_set_dict['AliasTarget'] = troposphere.route53.AliasTarget(
+                            HostedZoneId=hosted_zone_id,
+                            DNSName=record_set_config.resource_records[0]
+                        )
+                else:
+                    record_set_dict['Type'] = record_set_config.type
+                    record_set_dict['ResourceRecords'] = record_set_config.resource_records
+                    record_set_dict['TTL'] = record_set_config.ttl
+
+                record_set_res = troposphere.route53.RecordSet(**record_set_dict)
                 record_set_list.append(record_set_res)
 
             group_res = troposphere.route53.RecordSetGroup(
