@@ -113,3 +113,9 @@ class UnexpectedAwsResponse(PacoBaseException):
 
 class LambdaInvocationError(PacoBaseException):
     title = "AWS Lambda could not be invoked"
+
+class InvalidCloudFrontCertificateRegion(PacoBaseException):
+    title = "The CloudFront certificate must be in us-east-1"
+
+class InvalidAWSRegion(PacoBaseException):
+    title = "The region supplied is not a valid AWS region"
\ No newline at end of file
