@@ -1,9 +1,6 @@
-from paco.stack import StackGroup, StackTags
-from paco.core.yaml import YAML
+from paco.stack import StackGroup
 from paco.application.app_engine import ApplicationEngine
 
-yaml=YAML()
-yaml.default_flow_sytle = False
 
 class ApplicationStackGroup(StackGroup):
     def __init__(
@@ -25,7 +22,7 @@ class ApplicationStackGroup(StackGroup):
         self.env_ctx = env_ctx
         self.app = app
         self.aws_region = self.env_ctx.region
-        self.env_id = self.env_ctx.env_id
+        self.env_name = self.env_ctx.env.name
         self.stack_tags = stack_tags
 
     def init(self):
@@ -41,11 +38,3 @@ class ApplicationStackGroup(StackGroup):
         )
         self.app_engine.init()
 
-    def provision(self):
-        # Provision any SSL Cerificates
-        acm_ctl = self.paco_ctx.get_controller('ACM')
-        acm_ctl.provision()
-
-        # Provison Application Group
-        super().provision()
-
